"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.render = exports.ID = void 0;
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const server_1 = __importDefault(require("react-dom/server"));
const roam_client_1 = require("roam-client");
const util_1 = require("./util");
const Header = ({ links }) => {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("style", null, `#roamjs-header {
  margin: -8px;
  margin-bottom: 8px;
}

.roamjs-header-root {
  top: 0;
  left: auto;
  right: 0;
  position: sticky;
  width: 100%;
  display: flex;
  z-index: 1000;
  box-sizing: border-box;
  flex-shrink: 0;
  flex-direction: column;
  box-shadow: 0px 2px 4px -1px rgb(0 0 0 / 20%), 0px 4px 5px 0px rgb(0 0 0 / 14%), 0px 1px 10px 0px rgb(0 0 0 / 12%);
  transition: box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1) 0ms;
}

.roamjs-nav-root {
  justify-content: space-between;
  min-height: 64px;
  padding-left: 24px;
  padding-right: 24px;
  display: flex;
  position: relative;
  align-items: center;
}

.roamjs-home-header {
  font-size: 1.25rem;
  font-weight: 500;
  line-height: 1.6;
  letter-spacing: 0.0075em;
  margin: 0;
  padding: 0;
}

.roamjs-home-link {
  margin-left: 8px; 
  box-shadow: none;
}

.roamjs-links-container {
  min-height: 64px;
  padding-left: 24px;
  padding-right: 24px;
  display: flex;
  position: relative;
  align-items: center;
}

.roamjs-nav-link {
  margin-left: 8px;
}`),
        react_1.default.createElement("header", { className: "roamjs-header-root" },
            react_1.default.createElement("div", { className: "roamjs-nav-root" },
                react_1.default.createElement("h6", { className: "roamjs-home-header" },
                    react_1.default.createElement("a", { href: "/", className: "roamjs-home-link" }, "Home")),
                react_1.default.createElement("div", null,
                    react_1.default.createElement("div", { className: "roamjs-links-container" }, links.map((l) => (react_1.default.createElement("a", { href: l.href, className: "roamjs-nav-link", key: l.title }, l.title)))))))));
};
exports.ID = "roamjs-header";
if (process.env.CLIENT_SIDE) {
    react_dom_1.default.hydrate(react_1.default.createElement(Header, Object.assign({}, window.roamjsProps.header)), document.getElementById(exports.ID));
}
let cache = "";
const render = (dom, props, context) => {
    const componentProps = {
        links: (props["links"] || []).map(roam_client_1.extractTag).map((title) => ({
            title,
            href: context.convertPageNameToPath(title),
        })),
    };
    const innerHtml = cache ||
        (cache = server_1.default.renderToString(react_1.default.createElement(Header, Object.assign({}, componentProps))));
    const { document } = dom.window;
    const { body, head } = document;
    const container = document.createElement("div");
    container.id = exports.ID;
    body.insertBefore(container, body.firstElementChild);
    container.innerHTML = innerHtml;
    util_1.ensureReact(document);
    const propScript = document.createElement("script");
    propScript.innerHTML = `window.roamjsProps = {
    ...window.roamjsProps,
    header: ${JSON.stringify(componentProps)}
}`;
    propScript.type = 'text/javascript';
    head.appendChild(propScript);
    const componentScript = document.createElement("script");
    componentScript.src = "https://roamjs.com/static-site/header.js";
    componentScript.defer = true;
    head.appendChild(componentScript);
};
exports.render = render;
exports.default = Header;
