"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.render = exports.ID = void 0;
const react_1 = __importStar(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const server_1 = __importDefault(require("react-dom/server"));
const util_1 = require("./util");
const cytoscape_1 = __importDefault(require("cytoscape"));
const GraphWidget = ({ references, pageName }) => {
    const containerRef = react_1.useRef(null);
    const cyRef = react_1.useRef(null);
    react_1.useEffect(() => {
        const pathByTitle = Object.fromEntries(references.map((r) => [r.title, r.path]));
        cyRef.current = cytoscape_1.default({
            container: containerRef.current,
            elements: [
                ...[
                    pageName,
                    ...Array.from(new Set(references.map((a) => a.title))),
                ].map((id) => ({
                    data: { id },
                })),
                ...references.map(({ title: target, uid: id }) => ({
                    data: {
                        id,
                        source: pageName,
                        target,
                    },
                })),
            ],
            zoomingEnabled: false,
            panningEnabled: false,
            layout: {
                name: "random",
            },
            style: [
                {
                    selector: "node",
                    style: {
                        "background-color": "#888888",
                        label: "data(id)",
                        shape: "round-octagon",
                        color: "#ffffff",
                        "text-wrap": "wrap",
                        "text-halign": "center",
                        "text-valign": "center",
                        "text-max-width": "60",
                        "font-size": "12px",
                        width: 60,
                        height: 60,
                    },
                },
                {
                    selector: "edge",
                    style: {
                        width: 10,
                        "line-color": "#ccc",
                        "curve-style": "bezier",
                    },
                },
            ],
        });
        cyRef.current.nodes().forEach((n) => {
            n.on("click", () => {
                const title = n.id();
                if (title !== pageName) {
                    const path = pathByTitle[n.id()];
                    window.location.assign(path);
                }
            });
            n.on("mouseover", () => {
                if (containerRef.current)
                    containerRef.current.style.cursor = pathByTitle[n.id()]
                        ? "pointer"
                        : "not-allowed";
            });
            n.on("mouseout", () => {
                if (containerRef.current)
                    containerRef.current.style.cursor = "initial";
            });
        });
    }, [cyRef, containerRef, references, pageName]);
    return (react_1.default.createElement("div", { style: { border: "1px solid #eeeeee" } },
        react_1.default.createElement("h3", { style: {
                background: "#efefef",
                borderBottom: "1px solid #eeeeee",
                padding: 12,
                margin: 0,
            } }, "Map"),
        react_1.default.createElement("div", { ref: containerRef, style: { height: 400 } })));
};
const Sidebar = (_a) => {
    var { widgets } = _a, rest = __rest(_a, ["widgets"]);
    const widgetSet = new Set(widgets);
    return react_1.default.createElement(react_1.default.Fragment, null, widgetSet.has("graph") && react_1.default.createElement(GraphWidget, Object.assign({}, rest)));
};
exports.ID = "roamjs-sidebar";
if (process.env.CLIENT_SIDE) {
    react_dom_1.default.hydrate(react_1.default.createElement(Sidebar, Object.assign({}, window.roamjsProps.sidebar)), document.getElementById(exports.ID));
}
const render = (dom, props, context) => {
    var _a;
    const componentProps = {
        widgets: props["widgets"] || [],
        references: context.references.map((r) => ({
            title: r.title,
            uid: r.node.uid,
            path: context.convertPageNameToPath(r.title),
        })),
        pageName: context.pageName,
    };
    const innerHtml = server_1.default.renderToString(react_1.default.createElement(Sidebar, Object.assign({}, componentProps)));
    const { document } = dom.window;
    const { head } = document;
    const content = document.getElementById("content");
    if (content) {
        content.style.display = "flex";
        const container = document.createElement("div");
        const newContentContainer = document.createElement("div");
        newContentContainer.style.flexGrow = "1";
        container.id = exports.ID;
        container.innerHTML = innerHtml;
        container.style.width = "33%";
        container.style.minWidth = "200px";
        Array.from(content.children).forEach((c) => newContentContainer.appendChild(c));
        content.appendChild(newContentContainer);
        content.appendChild(container);
    }
    if (componentProps.widgets.includes("graph")) {
        (_a = document.getElementById("references")) === null || _a === void 0 ? void 0 : _a.remove();
    }
    util_1.ensureReact(document, head);
    util_1.ensureScript("sidebar", componentProps, document, head);
};
exports.render = render;
exports.default = Sidebar;
