import { RoamContext } from "roam-marked";
import { TreeNode, ViewType } from "roam-client";
import { HydratedTreeNode } from "./util";
declare type Filter = {
    rule: string;
    values: string[];
};
declare type InputConfig = {
    index?: string;
    filter?: Filter[];
    template?: string;
    referenceTemplate?: string;
    plugins?: Record<string, Record<string, string[]>>;
    theme?: Record<string, Record<string, string>>;
};
declare global {
    interface Window {
        fixViewType: (t: {
            c: TreeNode;
            v: ViewType;
        }) => TreeNode;
        getTreeByBlockId: (id: number) => TreeNode;
        getTreeByPageName: (name: string) => TreeNode[];
        roamjsProps: {
            [id: string]: Record<string, unknown>;
        };
    }
}
export declare const defaultConfig: Required<InputConfig>;
declare type PageContent = {
    content: HydratedTreeNode[];
    references: {
        title: string;
        node: HydratedTreeNode;
    }[];
    title: string;
    description: string;
    head: string;
    viewType: ViewType;
    uid: string;
};
export declare const renderHtmlFromPage: ({ outputPath, pageContent, p, config, pageMetadata, blockReferences, theme, }: {
    outputPath: string;
    pageContent: PageContent;
    p: string;
    config: Required<InputConfig>;
    pageMetadata: Record<string, string>;
    theme: string;
} & Pick<Required<RoamContext>, "blockReferences">) => void;
export declare const processSiteData: ({ pages, outputPath, config, info, }: {
    info: (s: string) => void;
    config: Required<InputConfig>;
    outputPath: string;
    pages: {
        [k: string]: PageContent;
    };
}) => InputConfig;
export declare const run: ({ roamUsername, roamPassword, roamGraph, logger, pathRoot, inputConfig, debug, }: {
    roamUsername: string;
    roamPassword: string;
    roamGraph: string;
    logger?: {
        info: (s: string) => void;
        error: (s: string) => void;
    } | undefined;
    pathRoot?: string | undefined;
    inputConfig?: InputConfig | undefined;
    debug?: boolean | undefined;
}) => Promise<InputConfig>;
export default run;
